@@ -22,6 +22,7 @@
 #include "lcfs-writer.h"
 #include "lcfs-utils.h"
 #include "lcfs-fsverity.h"
+#include "lcfs-erofs.h"
 #include "hash.h"
 
 #include <errno.h>
@@ -34,6 +35,8 @@
 #include <sys/xattr.h>
 #include <sys/param.h>
 #include <assert.h>
+#include <sys/mman.h>
+#include <sys/sysmacros.h>
 
 static void lcfs_node_remove_all_children(struct lcfs_node_s *node);
 static void lcfs_node_destroy(struct lcfs_node_s *node);
@@ -61,25 +64,14 @@ char *maybe_join_path(const char *a, const char *b)
 	return res;
 }
 
-static char *memdup(const char *s, size_t len)
-{
-	char *s2 = malloc(len);
-	if (s2 == NULL) {
-		errno = ENOMEM;
-		return NULL;
-	}
-	memcpy(s2, s, len);
-	return s2;
-}
-
 size_t hash_memory(const char *string, size_t len, size_t n_buckets)
 {
 	size_t i, value = 0;
 
 	for (i = 0; i < len; i++) {
-		value = (value * 31 + string[i]) % n_buckets;
+		value = (value * 31 + string[i]);
 	}
-	return value;
+	return value % n_buckets;
 }
 
 static struct lcfs_ctx_s *lcfs_new_ctx(struct lcfs_node_s *root,
@@ -122,7 +114,7 @@ int lcfs_clone_root(struct lcfs_ctx_s *ctx)
 
 	clone = lcfs_node_clone_deep(ctx->root);
 	if (clone == NULL) {
-		errno = -EINVAL;
+		errno = ENOMEM;
 		return -1;
 	}
 
@@ -155,14 +147,6 @@ int node_get_dtype(struct lcfs_node_s *node)
 	}
 }
 
-static int cmp_nodes(const void *a, const void *b)
-{
-	const struct lcfs_node_s *na = *((const struct lcfs_node_s **)a);
-	const struct lcfs_node_s *nb = *((const struct lcfs_node_s **)b);
-
-	return strcmp(na->name, nb->name);
-}
-
 static int cmp_xattr(const void *a, const void *b)
 {
 	const struct lcfs_xattr_s *na = a;
@@ -188,8 +172,6 @@ int lcfs_compute_tree(struct lcfs_ctx_s *ctx, struct lcfs_node_s *root)
 	ctx->min_mtim_nsec = root->inode.st_mtim_nsec;
 	ctx->has_acl = false;
 
-	node = root;
-
 	for (node = root, index = 0; node != NULL; node = node->next, index++) {
 		if ((node->inode.st_mode & S_IFMT) != S_IFDIR &&
 		    node->children_size != 0) {
@@ -211,9 +193,6 @@ int lcfs_compute_tree(struct lcfs_ctx_s *ctx, struct lcfs_node_s *root)
 		}
 
 		/* Canonical order */
-		if (node->children)
-			qsort(node->children, node->children_size,
-			      sizeof(node->children[0]), cmp_nodes);
 		if (node->xattrs)
 			qsort(node->xattrs, node->n_xattrs,
 			      sizeof(node->xattrs[0]), cmp_xattr);
@@ -255,7 +234,8 @@ int lcfs_compute_tree(struct lcfs_ctx_s *ctx, struct lcfs_node_s *root)
 	for (node = root; node != NULL; node = node->next) {
 		for (size_t i = 0; i < node->children_size; i++) {
 			struct lcfs_node_s *child = node->children[i];
-			if (child->link_to != NULL && !child->link_to->in_tree) {
+			struct lcfs_node_s *link_to = follow_links(child);
+			if (child->link_to != NULL && !link_to->in_tree) {
 				/* Link to inode outside tree */
 				errno = EINVAL;
 				return -1;
@@ -349,6 +329,27 @@ static int lcfs_close(struct lcfs_ctx_s *ctx)
 	return 0;
 }
 
+static void lcfs_write_update_version(struct lcfs_node_s *node,
+				      struct lcfs_write_options_s *options)
+{
+	/* Version 1 changed how whiteouts are handled */
+	if (options->version < 1 && options->max_version >= 1) {
+		int type = node->inode.st_mode & S_IFMT;
+
+		if (type == S_IFCHR && node->inode.st_rdev == makedev(0, 0)) {
+			options->version = 1;
+		}
+	}
+
+	for (size_t i = 0; i < node->children_size; ++i) {
+		struct lcfs_node_s *child = node->children[i];
+		if (child->link_to != NULL) {
+			continue;
+		}
+		lcfs_write_update_version(child, options);
+	}
+}
+
 int lcfs_write_to(struct lcfs_node_s *root, struct lcfs_write_options_s *options)
 {
 	enum lcfs_format_t format = options->format;
@@ -357,10 +358,23 @@ int lcfs_write_to(struct lcfs_node_s *root, struct lcfs_write_options_s *options
 
 	/* Check for unknown flags */
 	if ((options->flags & ~LCFS_FLAGS_MASK) != 0) {
-		errno = -EINVAL;
+		errno = EINVAL;
 		return -1;
 	}
 
+	if (options->version > LCFS_VERSION_MAX ||
+	    options->max_version > LCFS_VERSION_MAX) {
+		errno = EINVAL;
+		return -1;
+	}
+
+	if (options->max_version < options->version) {
+		options->max_version = options->version;
+	}
+
+	/* Update options->version up to options->max_version if needed */
+	lcfs_write_update_version(root, options);
+
 	ctx = lcfs_new_ctx(root, options);
 	if (ctx == NULL) {
 		errno = ENOMEM;
@@ -370,11 +384,12 @@ int lcfs_write_to(struct lcfs_node_s *root, struct lcfs_write_options_s *options
 	if (format == LCFS_FORMAT_EROFS)
 		res = lcfs_write_erofs_to(ctx);
 	else {
-		errno = -EINVAL;
+		errno = EINVAL;
 		res = -1;
 	}
 
 	if (res < 0) {
+		PROTECT_ERRNO;
 		lcfs_close(ctx);
 		return res;
 	}
@@ -388,13 +403,15 @@ int lcfs_write_to(struct lcfs_node_s *root, struct lcfs_write_options_s *options
 	return 0;
 }
 
-static int read_xattrs(struct lcfs_node_s *ret, int dirfd, const char *fname)
+static int read_xattrs(struct lcfs_node_s *ret, int dirfd, const char *fname,
+		       int buildflags)
 {
 	char path[PATH_MAX];
 	ssize_t list_size;
 	cleanup_free char *list = NULL;
 	ssize_t r = 0;
 	cleanup_fd int fd = -1;
+	bool user_xattr = (buildflags & LCFS_BUILD_USER_XATTRS) != 0;
 
 	fd = openat(dirfd, fname, O_PATH | O_NOFOLLOW | O_CLOEXEC, 0);
 	if (fd < 0)
@@ -421,6 +438,9 @@ static int read_xattrs(struct lcfs_node_s *ret, int dirfd, const char *fname)
 		ssize_t value_size;
 		cleanup_free char *value = NULL;
 
+		if (user_xattr && !str_has_prefix(it, "user."))
+			continue;
+
 		value_size = getxattr(path, it, NULL, 0);
 		if (value_size < 0) {
 			return value_size;
@@ -542,15 +562,65 @@ int lcfs_node_set_fsverity_from_fd(struct lcfs_node_s *node, int fd)
 	return lcfs_node_set_fsverity_from_content(node, &_fd, fsverity_read_cb);
 }
 
+static int read_content(int fd, size_t size, uint8_t *buf)
+{
+	int bytes_read;
+
+	while (size > 0) {
+		do
+			bytes_read = read(fd, buf, size);
+		while (bytes_read < 0 && errno == EINTR);
+
+		if (bytes_read == 0)
+			break;
+		else if (bytes_read < 0)
+			return -1;
+
+		size -= bytes_read;
+		buf += bytes_read;
+	}
+
+	if (size > 0) {
+		errno = ENODATA;
+		return -1;
+	}
+
+	return 0;
+}
+
+static void digest_to_path(const uint8_t *csum, char *buf)
+{
+	static const char hexchars[] = "0123456789abcdef";
+	uint32_t i, j;
+
+	for (i = 0, j = 0; i < LCFS_DIGEST_SIZE; i++, j += 2) {
+		uint8_t byte = csum[i];
+		if (i == 1)
+			buf[j++] = '/';
+		buf[j] = hexchars[byte >> 4];
+		buf[j + 1] = hexchars[byte & 0xF];
+	}
+	buf[j] = '\0';
+}
+
 struct lcfs_node_s *lcfs_load_node_from_file(int dirfd, const char *fname,
 					     int buildflags)
 {
-	struct lcfs_node_s *ret;
+	cleanup_node struct lcfs_node_s *ret = NULL;
 	struct stat sb;
 	int r;
 
 	if (buildflags & ~(LCFS_BUILD_SKIP_XATTRS | LCFS_BUILD_USE_EPOCH |
-			   LCFS_BUILD_SKIP_DEVICES | LCFS_BUILD_COMPUTE_DIGEST)) {
+			   LCFS_BUILD_SKIP_DEVICES | LCFS_BUILD_COMPUTE_DIGEST |
+			   LCFS_BUILD_NO_INLINE | LCFS_BUILD_USER_XATTRS |
+			   LCFS_BUILD_BY_DIGEST)) {
+		errno = EINVAL;
+		return NULL;
+	}
+
+	if ((buildflags & LCFS_BUILD_SKIP_XATTRS) &&
+	    (buildflags & LCFS_BUILD_USER_XATTRS)) {
+		/* These conflict */
 		errno = EINVAL;
 		return NULL;
 	}
@@ -570,19 +640,63 @@ struct lcfs_node_s *lcfs_load_node_from_file(int dirfd, const char *fname,
 	ret->inode.st_size = sb.st_size;
 
 	if ((sb.st_mode & S_IFMT) == S_IFREG) {
-		if (sb.st_size != 0 && (buildflags & LCFS_BUILD_COMPUTE_DIGEST) != 0) {
-			int fd = openat(dirfd, fname, O_RDONLY | O_CLOEXEC);
-			if (fd < 0) {
-				lcfs_node_unref(ret);
+		bool compute_digest = (buildflags & LCFS_BUILD_COMPUTE_DIGEST) != 0;
+		bool by_digest = (buildflags & LCFS_BUILD_BY_DIGEST) != 0;
+		bool no_inline = (buildflags & LCFS_BUILD_NO_INLINE) != 0;
+		bool is_zerosized = sb.st_size == 0;
+		bool do_digest = !is_zerosized && (compute_digest || by_digest);
+		bool do_inline = !is_zerosized && !no_inline &&
+				 sb.st_size <= LCFS_BUILD_INLINE_FILE_SIZE_LIMIT;
+
+		if (do_digest || do_inline) {
+			cleanup_fd int fd =
+				openat(dirfd, fname, O_RDONLY | O_CLOEXEC);
+			if (fd < 0)
 				return NULL;
+			if (do_digest) {
+				r = lcfs_node_set_fsverity_from_fd(ret, fd);
+				if (r < 0)
+					return NULL;
+
+				if (by_digest) {
+					const uint8_t *digest =
+						lcfs_node_get_fsverity_digest(ret);
+					char digest_path[LCFS_DIGEST_SIZE * 2 + 2];
+					digest_to_path(digest, digest_path);
+					r = lcfs_node_set_payload(ret, digest_path);
+					if (r < 0)
+						return NULL;
+
+					/* We just computed digest to get the payoad path */
+					if (!compute_digest)
+						ret->digest_set = false;
+				}
+
+				/* In case we re-read below */
+				lseek(fd, 0, SEEK_SET);
 			}
-			r = lcfs_node_set_fsverity_from_fd(ret, fd);
-			close(fd);
-			if (r < 0) {
-				lcfs_node_unref(ret);
-				return NULL;
+			if (do_inline) {
+				uint8_t buf[LCFS_BUILD_INLINE_FILE_SIZE_LIMIT];
+
+				r = read_content(fd, sb.st_size, buf);
+				if (r < 0)
+					return NULL;
+				r = lcfs_node_set_content(ret, buf, sb.st_size);
+				if (r < 0)
+					return NULL;
 			}
 		}
+	} else if ((sb.st_mode & S_IFMT) == S_IFLNK) {
+		char target[PATH_MAX + 1];
+
+		r = readlinkat(dirfd, fname, target, sizeof(target));
+		if (r < 0)
+			return NULL;
+
+		target[r] = '\0';
+		r = lcfs_node_set_payload(ret, target);
+		if (r < 0)
+			return NULL;
 	}
 
 	if ((buildflags & LCFS_BUILD_USE_EPOCH) == 0) {
@@ -591,27 +705,87 @@ struct lcfs_node_s *lcfs_load_node_from_file(int dirfd, const char *fname,
 	}
 
 	if ((buildflags & LCFS_BUILD_SKIP_XATTRS) == 0) {
-		r = read_xattrs(ret, dirfd, fname);
-		if (r < 0) {
-			lcfs_node_unref(ret);
+		r = read_xattrs(ret, dirfd, fname, buildflags);
+		if (r < 0)
 			return NULL;
-		}
 	}
 
-	return ret;
+	return steal_pointer(&ret);
+}
+
+int lcfs_version_from_fd(int fd)
+{
+	struct lcfs_erofs_header_s *header;
+
+	header = mmap(0, sizeof(struct lcfs_erofs_header_s), PROT_READ,
+		      MAP_PRIVATE, fd, 0);
+	if (header == MAP_FAILED) {
+		return -1;
+	}
+	if (lcfs_u32_from_file(header->magic) != LCFS_EROFS_MAGIC ||
+	    lcfs_u32_from_file(header->version) != LCFS_EROFS_VERSION) {
+		errno = EINVAL;
+		return -1;
+	}
+
+	return lcfs_u32_from_file(header->composefs_version);
+}
+
+struct lcfs_node_s *lcfs_load_node_from_fd(int fd)
+{
+	struct lcfs_node_s *node;
+	uint8_t *image_data;
+	size_t image_data_size;
+	struct stat s;
+	int errsv;
+	int r;
+
+	r = fstat(fd, &s);
+	if (r < 0) {
+		return NULL;
+	}
+
+	image_data_size = s.st_size;
+
+	image_data = mmap(0, image_data_size, PROT_READ, MAP_PRIVATE, fd, 0);
+	if (image_data == MAP_FAILED) {
+		return NULL;
+	}
+
+	node = lcfs_load_node_from_image(image_data, image_data_size);
+	if (node == NULL) {
+		errsv = errno;
+		munmap(image_data, image_data_size);
+		errno = errsv;
+		return NULL;
+	}
+
+	munmap(image_data, image_data_size);
+
+	return node;
 }
 
 int lcfs_node_set_payload(struct lcfs_node_s *node, const char *payload)
 {
-	node->payload = strdup(payload);
-	if (node->payload == NULL) {
-		errno = ENOMEM;
-		return -1;
+	char *dup = NULL;
+	if (payload) {
+		dup = strdup(payload);
+		if (dup == NULL) {
+			errno = ENOMEM;
+			return -1;
+		}
 	}
+	free(node->payload);
+	node->payload = dup;
 
 	return 0;
 }
 
+const char *lcfs_node_get_payload(struct lcfs_node_s *node)
+{
+	return node->payload;
+}
+
 const uint8_t *lcfs_node_get_fsverity_digest(struct lcfs_node_s *node)
 {
 	if (node->digest_set)
@@ -627,6 +801,31 @@ void lcfs_node_set_fsverity_digest(struct lcfs_node_s *node,
 	memcpy(node->digest, digest, LCFS_DIGEST_SIZE);
 }
 
+int lcfs_node_set_content(struct lcfs_node_s *node, const uint8_t *data,
+			  size_t data_size)
+{
+	uint8_t *dup = NULL;
+
+	if (data && data_size != 0) {
+		dup = malloc(data_size);
+		if (dup == NULL) {
+			errno = ENOMEM;
+			return -1;
+		}
+		memcpy(dup, data, data_size);
+	}
+	free(node->content);
+	node->content = dup;
+	node->inode.st_size = data_size;
+
+	return 0;
+}
+
+const uint8_t *lcfs_node_get_content(struct lcfs_node_s *node)
+{
+	return node->content;
+}
+
 const char *lcfs_node_get_name(struct lcfs_node_s *node)
 {
 	return node->name;
@@ -699,8 +898,14 @@ uint64_t lcfs_node_get_size(struct lcfs_node_s *node)
 	return node->inode.st_size;
 }
 
+/* Clears content if size changes */
 void lcfs_node_set_size(struct lcfs_node_s *node, uint64_t size)
 {
+	if (size == node->inode.st_size)
+		return;
+
+	free(node->content);
+	node->content = NULL;
 	node->inode.st_size = size;
 }
 
@@ -716,20 +921,54 @@ void lcfs_node_get_mtime(struct lcfs_node_s *node, struct timespec *time)
 	time->tv_nsec = node->inode.st_mtim_nsec;
 }
 
-struct lcfs_node_s *lcfs_node_lookup_child(struct lcfs_node_s *node, const char *name)
+static struct lcfs_node_s *lcfs_node_bsearch_child(struct lcfs_node_s *node,
+						   const char *name, size_t *pos)
 {
-	size_t i;
+	size_t start = 0, end = node->children_size;
 
-	for (i = 0; i < node->children_size; ++i) {
-		struct lcfs_node_s *child = node->children[i];
-
-		if (child->name && strcmp(child->name, name) == 0)
+	/* We start by looking at the end, as this is common when we insert in sorted order */
+	if (end > 0) {
+		struct lcfs_node_s *child = node->children[end - 1];
+		int cmp = strcmp(name, child->name);
+		if (cmp == 0) {
+			if (pos)
+				*pos = end - 1;
 			return child;
+		}
+		if (cmp > 0) {
+			if (pos)
+				*pos = end;
+			return NULL;
+		}
 	}
 
+	while (end > start) {
+		size_t mid = (start + end) / 2;
+		struct lcfs_node_s *child = node->children[mid];
+
+		int cmp = strcmp(name, child->name);
+		if (cmp == 0) {
+			if (pos)
+				*pos = mid;
+			return child;
+		}
+		if (cmp < 0) {
+			end = mid;
+		} else {
+			start = mid + 1;
+		}
+	}
+
+	if (pos)
+		*pos = start;
 	return NULL;
 }
 
+struct lcfs_node_s *lcfs_node_lookup_child(struct lcfs_node_s *node, const char *name)
+{
+	return lcfs_node_bsearch_child(node, name, NULL);
+}
+
 struct lcfs_node_s *lcfs_node_get_parent(struct lcfs_node_s *node)
 {
 	return node->parent;
@@ -742,12 +981,16 @@ void lcfs_node_make_hardlink(struct lcfs_node_s *node, struct lcfs_node_s *targe
 	target->inode.st_nlink++;
 }
 
+struct lcfs_node_s *lcfs_node_get_hardlink_target(struct lcfs_node_s *node)
+{
+	return node->link_to;
+}
+
 int lcfs_node_add_child(struct lcfs_node_s *parent, struct lcfs_node_s *child,
 			const char *name)
 {
 	struct lcfs_node_s **new_children;
-	size_t new_size;
-	char *name_copy;
+	size_t new_capacity;
 
 	if ((parent->inode.st_mode & S_IFMT) != S_IFDIR) {
 		errno = ENOTDIR;
@@ -765,31 +1008,45 @@ int lcfs_node_add_child(struct lcfs_node_s *parent, struct lcfs_node_s *child,
 		return -1;
 	}
 
-	if (lcfs_node_lookup_child(parent, name) != NULL) {
+	if (parent->children_capacity == parent->children_size) {
+		if (parent->children_size == 0)
+			new_capacity = 16;
+		else
+			new_capacity = parent->children_capacity * 2;
+
+		new_children = reallocarray(parent->children,
+					    sizeof(*parent->children), new_capacity);
+		if (new_children == NULL) {
+			errno = ENOMEM;
+			return -1;
+		}
+
+		parent->children = new_children;
+		parent->children_capacity = new_capacity;
+	}
+
+	size_t insert_pos;
+	struct lcfs_node_s *existing =
+		lcfs_node_bsearch_child(parent, name, &insert_pos);
+	if (existing != NULL) {
 		errno = EEXIST;
 		return -1;
 	}
 
-	name_copy = strdup(name);
+	char *name_copy = strdup(name);
 	if (name_copy == NULL) {
 		errno = ENOMEM;
 		return -1;
 	}
 
-	new_size = parent->children_size + 1;
+	if (insert_pos < parent->children_size)
+		memmove(parent->children + insert_pos + 1,
+			parent->children + insert_pos,
+			(parent->children_size - insert_pos) *
+				sizeof(struct lcfs_node_s *));
 
-	new_children = reallocarray(parent->children, sizeof(*parent->children),
-				    new_size);
-	if (new_children == NULL) {
-		errno = ENOMEM;
-		free(name_copy);
-		return -1;
-	}
-
-	parent->children = new_children;
-
-	parent->children[parent->children_size] = child;
-	parent->children_size = new_size;
+	parent->children[insert_pos] = child;
+	parent->children_size += 1;
 	child->parent = parent;
 	child->name = name_copy;
 
@@ -824,6 +1081,7 @@ void lcfs_node_unref(struct lcfs_node_s *node)
 
 	free(node->name);
 	free(node->payload);
+	free(node->content);
 
 	for (i = 0; i < node->n_xattrs; i++) {
 		free(node->xattrs[i].key);
@@ -857,7 +1115,9 @@ static void lcfs_node_destroy(struct lcfs_node_s *node)
 
 struct lcfs_node_s *lcfs_node_clone(struct lcfs_node_s *node)
 {
-	struct lcfs_node_s *new = lcfs_node_new();
+	cleanup_node struct lcfs_node_s *new = lcfs_node_new();
+	if (new == NULL)
+		return NULL;
 
 	/* Note: This copies only data, not structure like name or children */
 
@@ -869,13 +1129,22 @@ struct lcfs_node_s *lcfs_node_clone(struct lcfs_node_s *node)
 	if (node->payload) {
 		new->payload = strdup(node->payload);
 		if (new->payload == NULL)
-			goto fail;
+			return NULL;
+		;
+	}
+
+	if (node->content) {
+		new->content = malloc(node->inode.st_size);
+		if (new->content == NULL)
+			return NULL;
+		;
+		memcpy(new->content, node->content, node->inode.st_size);
 	}
 
 	if (node->n_xattrs > 0) {
 		new->xattrs = malloc(sizeof(struct lcfs_xattr_s) * node->n_xattrs);
 		if (new->xattrs == NULL)
-			goto fail;
+			return NULL;
 		for (size_t i = 0; i < node->n_xattrs; i++) {
 			char *key = strdup(node->xattrs[i].key);
 			char *value = memdup(node->xattrs[i].value,
@@ -883,7 +1152,7 @@ struct lcfs_node_s *lcfs_node_clone(struct lcfs_node_s *node)
 			if (key == NULL || value == NULL) {
 				free(key);
 				free(value);
-				goto fail;
+				return NULL;
 			}
 			new->xattrs[i].key = key;
 			new->xattrs[i].value = value;
@@ -896,11 +1165,7 @@ struct lcfs_node_s *lcfs_node_clone(struct lcfs_node_s *node)
 	memcpy(new->digest, node->digest, LCFS_DIGEST_SIZE);
 	new->inode = node->inode;
 
-	return new;
-
-fail:
-	lcfs_node_unref(new);
-	return NULL;
+	return steal_pointer(&new);
 }
 
 struct lcfs_node_mapping_s {
@@ -917,7 +1182,9 @@ struct lcfs_clone_data {
 static struct lcfs_node_s *_lcfs_node_clone_deep(struct lcfs_node_s *node,
 						 struct lcfs_clone_data *data)
 {
-	struct lcfs_node_s *new = lcfs_node_clone(node);
+	cleanup_node struct lcfs_node_s *new = lcfs_node_clone(node);
+	if (new == NULL)
+		return NULL;
 
 	if (data->n_mappings >= data->allocated_mappings) {
 		struct lcfs_node_mapping_s *new_mapping;
@@ -928,7 +1195,7 @@ static struct lcfs_node_s *_lcfs_node_clone_deep(struct lcfs_node_s *node,
 					   sizeof(struct lcfs_node_mapping_s),
 					   data->allocated_mappings);
 		if (new_mapping == NULL)
-			goto fail;
+			return NULL;
 		data->mapping = new_mapping;
 	}
 
@@ -940,17 +1207,13 @@ static struct lcfs_node_s *_lcfs_node_clone_deep(struct lcfs_node_s *node,
 		struct lcfs_node_s *child = node->children[i];
 		struct lcfs_node_s *new_child = _lcfs_node_clone_deep(child, data);
 		if (new_child == NULL)
-			goto fail;
+			return NULL;
 
 		if (lcfs_node_add_child(new, new_child, child->name) < 0)
-			goto fail;
+			return NULL;
 	}
 
-	return new;
-
-fail:
-	lcfs_node_unref(new);
-	return NULL;
+	return steal_pointer(&new);
 }
 
 /* Rewrite all hardlinks according to mapping */
@@ -1162,6 +1425,11 @@ int lcfs_node_set_xattr(struct lcfs_node_s *node, const char *name,
 	char *k, *v;
 	ssize_t index = find_xattr(node, name);
 
+	if (value_len > UINT16_MAX) {
+		errno = EINVAL;
+		return -1;
+	}
+
 	if (index >= 0) {
 		/* Already set, replace */
 		struct lcfs_xattr_s *xattr = &node->xattrs[index];
@@ -1177,6 +1445,11 @@ int lcfs_node_set_xattr(struct lcfs_node_s *node, const char *name,
 		return 0;
 	}
 
+	if (node->n_xattrs == UINT16_MAX) {
+		errno = EINVAL;
+		return -1;
+	}
+
 	xattrs = realloc(node->xattrs,
 			 (node->n_xattrs + 1) * sizeof(struct lcfs_xattr_s));
 	if (xattrs == NULL) {
@@ -1201,3 +1474,27 @@ int lcfs_node_set_xattr(struct lcfs_node_s *node, const char *name,
 
 	return 0;
 }
+
+/* This is an internal function.
+ * Be careful to not cause duplicates if new_name already exist */
+int lcfs_node_rename_xattr(struct lcfs_node_s *node, size_t index, const char *new_name)
+{
+	struct lcfs_xattr_s *xattr;
+	cleanup_free char *dup = NULL;
+
+	dup = strdup(new_name);
+	if (dup == NULL) {
+		errno = ENOMEM;
+		return -1;
+	}
+
+	if (index >= node->n_xattrs) {
+		errno = EINVAL;
+		return -1;
+	}
+
+	xattr = &node->xattrs[index];
+	free(xattr->key);
+	xattr->key = steal_pointer(&dup);
+	return 0;
+}
