@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -24,7 +22,8 @@
 G_BEGIN_DECLS
 
 #define OSTREE_TYPE_DEPLOYMENT (ostree_deployment_get_type ())
-#define OSTREE_DEPLOYMENT(inst) (G_TYPE_CHECK_INSTANCE_CAST ((inst), OSTREE_TYPE_DEPLOYMENT, OstreeDeployment))
+#define OSTREE_DEPLOYMENT(inst) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((inst), OSTREE_TYPE_DEPLOYMENT, OstreeDeployment))
 #define OSTREE_IS_DEPLOYMENT(inst) (G_TYPE_CHECK_INSTANCE_TYPE ((inst), OSTREE_TYPE_DEPLOYMENT))
 
 /**
@@ -49,12 +48,8 @@ _OSTREE_PUBLIC
 gboolean ostree_deployment_equal (gconstpointer ap, gconstpointer bp);
 
 _OSTREE_PUBLIC
-OstreeDeployment * ostree_deployment_new (int    index,
-                                  const char  *osname,
-                                  const char  *csum,
-                                  int    deployserial,
-                                  const char  *bootcsum,
-                                  int    bootserial);
+OstreeDeployment *ostree_deployment_new (int index, const char *osname, const char *csum,
+                                         int deployserial, const char *bootcsum, int bootserial);
 
 _OSTREE_PUBLIC
 int ostree_deployment_get_index (OstreeDeployment *self);
@@ -76,6 +71,8 @@ GKeyFile *ostree_deployment_get_origin (OstreeDeployment *self);
 _OSTREE_PUBLIC
 gboolean ostree_deployment_is_staged (OstreeDeployment *self);
 _OSTREE_PUBLIC
+gboolean ostree_deployment_is_finalization_locked (OstreeDeployment *self);
+_OSTREE_PUBLIC
 gboolean ostree_deployment_is_pinned (OstreeDeployment *self);
 
 _OSTREE_PUBLIC
@@ -96,10 +93,12 @@ OstreeDeployment *ostree_deployment_clone (OstreeDeployment *self);
 _OSTREE_PUBLIC
 char *ostree_deployment_get_origin_relpath (OstreeDeployment *self);
 
-typedef enum {
+typedef enum
+{
   OSTREE_DEPLOYMENT_UNLOCKED_NONE,
   OSTREE_DEPLOYMENT_UNLOCKED_DEVELOPMENT,
-  OSTREE_DEPLOYMENT_UNLOCKED_HOTFIX
+  OSTREE_DEPLOYMENT_UNLOCKED_HOTFIX,
+  OSTREE_DEPLOYMENT_UNLOCKED_TRANSIENT,
 } OstreeDeploymentUnlockedState;
 
 _OSTREE_PUBLIC
