@@ -490,9 +490,9 @@ ostree_mutable_tree_fill_empty_from_dirtree (OstreeMutableTree *self, OstreeRepo
                                              const char *contents_checksum,
                                              const char *metadata_checksum)
 {
-  g_return_val_if_fail (repo, FALSE);
-  g_return_val_if_fail (contents_checksum, FALSE);
-  g_return_val_if_fail (metadata_checksum, FALSE);
+  g_assert (repo);
+  g_assert (contents_checksum);
+  g_assert (metadata_checksum);
 
   switch (self->state)
     {
@@ -505,8 +505,9 @@ ostree_mutable_tree_fill_empty_from_dirtree (OstreeMutableTree *self, OstreeRepo
         if (g_strcmp0 (empty_tree_csum, contents_checksum) == 0)
           {
             /* Adding an empty tree to a full one - stick with the old contents */
-            contents_checksum = self->contents_checksum;
-            break;
+            g_set_object (&self->repo, repo);
+            ostree_mutable_tree_set_metadata_checksum (self, metadata_checksum);
+            return TRUE;
           }
         else
           return FALSE;
@@ -546,7 +547,7 @@ gboolean
 ostree_mutable_tree_walk (OstreeMutableTree *self, GPtrArray *split_path, guint start,
                           OstreeMutableTree **out_subdir, GError **error)
 {
-  g_return_val_if_fail (start < split_path->len, FALSE);
+  g_assert_cmpuint (start, <, split_path->len);
 
   if (start == split_path->len - 1)
     {
