@@ -195,7 +195,7 @@ create_file_copy_from_input_at (OstreeRepo *repo, OstreeRepoCheckoutAtOptions *o
   g_autoptr (GVariant) modified_xattrs = NULL;
 
   /* If we're doing SELinux labeling, prepare it */
-  if (sepolicy_enabled && ostree_sepolicy_host_enabled (options->sepolicy))
+  if (sepolicy_enabled && _ostree_sepolicy_host_enabled (options->sepolicy))
     {
       /* If doing sepolicy path-based labeling, we don't want to set the
        * security.selinux attr via the generic xattr paths in either the symlink
@@ -1045,7 +1045,7 @@ checkout_tree_at_recurse (OstreeRepo *self, OstreeRepoCheckoutAtOptions *options
     };
 
     /* If we're doing SELinux labeling, prepare it */
-    if (sepolicy_enabled && ostree_sepolicy_host_enabled (options->sepolicy))
+    if (sepolicy_enabled && _ostree_sepolicy_host_enabled (options->sepolicy))
       {
         /* We'll set the xattr via setfscreatecon(), so don't do it via generic xattrs below. */
         modified_xattrs = _ostree_filter_selinux_xattr (xattrs);
@@ -1062,6 +1062,22 @@ checkout_tree_at_recurse (OstreeRepo *self, OstreeRepoCheckoutAtOptions *options
         if (!glnx_shutil_rm_rf_at (destination_parent_fd, destination_name, cancellable, error))
           return FALSE;
       }
+    else if (options->process_whiteouts
+             && options->overwrite_mode == OSTREE_REPO_CHECKOUT_OVERWRITE_UNION_FILES)
+      {
+        /* In this mode, we're flattening in a manner similar to overlayfs, so ensure
+         * any non-directory content there is gone. /
+         */
+        struct stat stbuf;
+        if (!glnx_fstatat_allow_noent (destination_parent_fd, destination_name, &stbuf,
+                                       AT_SYMLINK_NOFOLLOW, error))
+          return FALSE;
+        if (errno == 0 && !S_ISDIR (stbuf.st_mode))
+          {
+            if (!glnx_shutil_rm_rf_at (destination_parent_fd, destination_name, cancellable, error))
+              return FALSE;
+          }
+      }
 
     /* Create initially with mode 0700, then chown/chmod only when we're
      * done.  This avoids anyone else being able to operate on partially
