@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -25,10 +23,8 @@
 
 G_BEGIN_DECLS
 
-gboolean _ostree_read_varuint64 (const guint8   *buf,
-                                 gsize           buflen,
-                                 guint64        *out_value,
-                                 gsize          *bytes_read);
+gboolean _ostree_read_varuint64 (const guint8 *buf, gsize buflen, guint64 *out_value,
+                                 gsize *bytes_read);
 
 void _ostree_write_varuint64 (GString *buf, guint64 n);
 
