@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Authors:
  *  - Philip Withnall <withnall@endlessm.com>
@@ -33,8 +31,8 @@
 static void
 test_bloom_init (void)
 {
-  g_autoptr(OstreeBloom) bloom = NULL;
-  g_autoptr(GBytes) bytes = NULL;
+  g_autoptr (OstreeBloom) bloom = NULL;
+  g_autoptr (GBytes) bytes = NULL;
 
   bloom = ostree_bloom_new (1, 1, ostree_str_bloom_hash);
   g_assert_cmpuint (ostree_bloom_get_size (bloom), ==, 1);
@@ -55,18 +53,12 @@ test_bloom_init (void)
 static void
 test_bloom_construction (void)
 {
-  g_autoptr(OstreeBloom) bloom = NULL;
-  g_autoptr(OstreeBloom) immutable_bloom = NULL;
-  g_autoptr(GBytes) bytes = NULL;
+  g_autoptr (OstreeBloom) bloom = NULL;
+  g_autoptr (OstreeBloom) immutable_bloom = NULL;
+  g_autoptr (GBytes) bytes = NULL;
   gsize i;
-  const gchar *members[] =
-    {
-      "hello", "there", "these", "are", "test", "strings"
-    };
-  const gchar *non_members[] =
-    {
-      "not", "an", "element"
-    };
+  const gchar *members[] = { "hello", "there", "these", "are", "test", "strings" };
+  const gchar *non_members[] = { "not", "an", "element" };
   const gsize n_bytes = 256;
   const guint8 k = 8;
   const OstreeBloomHashFunc hash = ostree_str_bloom_hash;
@@ -96,7 +88,7 @@ test_bloom_construction (void)
 static void
 test_bloom_empty (void)
 {
-  g_autoptr(OstreeBloom) bloom = NULL;
+  g_autoptr (OstreeBloom) bloom = NULL;
   const gsize n_bytes = 256;
   const guint8 k = 8;
   const OstreeBloomHashFunc hash = ostree_str_bloom_hash;
@@ -113,12 +105,9 @@ test_bloom_empty (void)
 static void
 test_bloom_membership_during_construction (void)
 {
-  g_autoptr(OstreeBloom) bloom = NULL;
+  g_autoptr (OstreeBloom) bloom = NULL;
   gsize i, j;
-  const gchar *members[] =
-    {
-      "hello", "there", "these", "are", "test", "strings"
-    };
+  const gchar *members[] = { "hello", "there", "these", "are", "test", "strings" };
   const gsize n_bytes = 256;
   const guint8 k = 8;
   const OstreeBloomHashFunc hash = ostree_str_bloom_hash;
@@ -142,14 +131,16 @@ test_bloom_membership_during_construction (void)
     }
 }
 
-int main (int argc, char **argv)
+int
+main (int argc, char **argv)
 {
   g_test_init (&argc, &argv, NULL);
 
   g_test_add_func ("/bloom/init", test_bloom_init);
   g_test_add_func ("/bloom/construction", test_bloom_construction);
   g_test_add_func ("/bloom/empty", test_bloom_empty);
-  g_test_add_func ("/bloom/membership-during-construction", test_bloom_membership_during_construction);
+  g_test_add_func ("/bloom/membership-during-construction",
+                   test_bloom_membership_during_construction);
 
-  return g_test_run();
+  return g_test_run ();
 }
